pub fn rdma_supported() -> boolExpand description
Whether any RDMA backend is available on this system.
Returns true if ibverbs hardware is present, or if TCP fallback
is enabled via config::RDMA_ALLOW_TCP_FALLBACK.
pub fn rdma_supported() -> boolWhether any RDMA backend is available on this system.
Returns true if ibverbs hardware is present, or if TCP fallback
is enabled via config::RDMA_ALLOW_TCP_FALLBACK.